@@ -8,7 +8,7 @@
 
 #include <string.h>
 #include <libgnome/gnome-util.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include <libxml/tree.h>
 
@@ -63,6 +63,7 @@ struct _CDDisplayPrivate {
 enum {
 	PLAYMODE_CHANGED,
 	LOOPMODE_CHANGED,
+	REMAINING_TIME,
 	LAST_SIGNAL
 };
 
@@ -71,8 +72,8 @@ static gulong display_signals[LAST_SIGNAL] = { 0, };
 static char *default_text[CD_DISPLAY_END] = {
 	"0:00",
 	" ",
-	N_("Unknown artist"),
-	N_("Unknown disc")
+	N_("Unknown Artist"),
+	N_("Unknown Album")
 };
 
 static void
@@ -487,11 +488,23 @@ button_press_event (GtkWidget *widget,
 {
 	CDDisplay *disp = CD_DISPLAY (widget);
 	CDDisplayPrivate *priv = disp->priv;
-
+	GnomeCDText *text;
+	PangoRectangle rect;
+	
+	text = priv->layout[CD_DISPLAY_LINE_TIME];
+	pango_layout_get_extents (text->layout, NULL, &rect);
+	text->height = rect.height / 1000;
+	
 	if (ev->button != 1) {
 		return FALSE;
 	}
-	
+
+    /* Check the remaining time mode */
+    if (ev->x <= (rect.width / 1000) && ev->y <= text->height) {
+        g_signal_emit (G_OBJECT (widget), display_signals[REMAINING_TIME], 0, NULL);
+        return TRUE;
+	}
+
 	/* Check the play mode */
 	if (ev->x >= priv->track->rect.x &&
 	    ev->x <= (priv->track->rect.x + priv->track->rect.width) &&
@@ -553,6 +566,14 @@ class_init (CDDisplayClass *klass)
 							  g_cclosure_marshal_VOID__INT,
 							  G_TYPE_NONE,
 							  1, G_TYPE_INT);
+	display_signals[REMAINING_TIME] = g_signal_new ("remainingtime-mode-changed",
+							  G_TYPE_FROM_CLASS (klass),
+							  G_SIGNAL_RUN_FIRST | G_SIGNAL_NO_RECURSE,
+							  G_STRUCT_OFFSET (CDDisplayClass, remainingtime_mode_changed),
+							  NULL, NULL,
+							  g_cclosure_marshal_VOID__INT,
+							  G_TYPE_NONE,
+							  1, G_TYPE_INT);
 	display_signals[LOOPMODE_CHANGED] = g_signal_new ("loopmode-changed",
 							  G_TYPE_FROM_CLASS (klass),
 							  G_SIGNAL_RUN_FIRST | G_SIGNAL_NO_RECURSE,
@@ -675,6 +696,33 @@ cd_display_new (void)
 	return CD_DISPLAY (disp);
 }
 
+void
+cd_display_set_style (CDDisplay *disp)
+{
+	CDDisplayPrivate *priv;
+	CDDisplayLine line;
+	GnomeCDText *text;
+	PangoRectangle rect;
+	int height, max_width = 0;
+
+	priv = disp->priv;
+
+	for (line = CD_DISPLAY_LINE_TIME; line < CD_DISPLAY_END; line++) {
+		text = priv->layout[line];
+		height = priv->height - text->height;
+
+		pango_layout_set_text (text->layout, text->text, text->length);
+		pango_layout_get_extents (text->layout, NULL, &rect);
+		text->height = rect.height / 1000;
+
+		priv->height = height + text->height;
+		max_width = MAX (priv->max_width, rect.width / 1000);
+	}
+
+	priv->max_width = max_width;
+	gtk_widget_queue_resize (GTK_WIDGET (disp));
+}
+
 const char *
 cd_display_get_line (CDDisplay *disp,
 		     int line)
@@ -789,29 +837,30 @@ cd_display_parse_theme (CDDisplay *disp,
 
 			location = xmlGetProp (cur, (const xmlChar *) "location");
 			if (location != NULL) {
-				char *file, *full;
+				guchar *file;
+				char *full;
 
 				file = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
-				full = make_fullname (cd_theme->name, file);
+				full = make_fullname (cd_theme->name, (char *)file);
 				xmlFree (file);
 				
-				if (xmlStrcmp (location, "top-left") == 0) {
+				if (xmlStrcmp (location, (guchar *)"top-left") == 0) {
 					theme->corners[TOPLEFT] = cd_image_new (full, 0, 0);
-				} else if (xmlStrcmp (location, "top-right") == 0) {
+				} else if (xmlStrcmp (location, (guchar *)"top-right") == 0) {
 					theme->corners[TOPRIGHT] = cd_image_new (full, 48, 0);
-				} else if (xmlStrcmp (location, "bottom-right") == 0) {
+				} else if (xmlStrcmp (location, (guchar *)"bottom-right") == 0) {
 					theme->corners[BOTTOMRIGHT] = cd_image_new (full, 48, 32);
-				} else if (xmlStrcmp (location, "bottom-left") == 0) {
+				} else if (xmlStrcmp (location, (guchar *)"bottom-left") == 0) {
 					theme->corners[BOTTOMLEFT] = cd_image_new (full, 0, 32);
-				} else if (xmlStrcmp (location, "left") == 0) {
+				} else if (xmlStrcmp (location, (guchar *)"left") == 0) {
 					theme->straights[LEFT] = cd_image_new (full, 0, 16);
-				} else if (xmlStrcmp (location, "right") == 0) {
+				} else if (xmlStrcmp (location, (guchar *)"right") == 0) {
 					theme->straights[RIGHT] = cd_image_new (full, 48, 16);
-				} else if (xmlStrcmp (location, "top") == 0) {
+				} else if (xmlStrcmp (location, (guchar *)"top") == 0) {
 					theme->straights[TOP] = cd_image_new (full, 16, 0);
-				} else if (xmlStrcmp (location, "bottom") == 0) {
+				} else if (xmlStrcmp (location, (guchar *)"bottom") == 0) {
 					theme->straights[BOTTOM] = cd_image_new (full, 16, 32);
-				} else if (xmlStrcmp (location, "middle") == 0) {
+				} else if (xmlStrcmp (location, (guchar *)"middle") == 0) {
 					theme->middle = cd_image_new (full, 16, 16);
 				} else {
 					/** Hmmmmm */
