@@ -157,8 +157,13 @@ skip_to_track (GtkWidget *item,
 	msf.frame = 0;
 
 	if (gcd->cdrom->playmode == GNOME_CDROM_SINGLE_TRACK) {
-		end_track = track + 2;
-		endmsf = &msf;
+		if (gcd->disc_info && (track + 1) >= gcd->disc_info->ntracks) {
+			end_track = -1;
+			endmsf = NULL;
+		} else {	
+			end_track = track + 2;
+			endmsf = &msf;
+		}
 	} else {
 		end_track = -1;
 		endmsf = NULL;
@@ -342,7 +347,7 @@ window_destroy_cb (GtkWidget *window,
 	destroy_track_editor ();
 	
 	/* Remove the gconf volume notify*/
-	gconf_client_notify_remove (client, volume_notify_id);
+	gconf_client_notify_remove (gcd->client, volume_notify_id);
 	g_object_unref (gcd->cdrom);
 	bonobo_main_quit ();
 }
@@ -462,7 +467,7 @@ make_popup_menu (GnomeCD *gcd, GdkEventButton *event, gboolean iconify)
 		/* Disable the first four menu items when no disc is inserted
 		 * Update as per the buttons on the main window
 		 */
-		if (status->cd == GNOME_CDROM_STATUS_NO_DISC && i < 4) 
+		if ((status->cd == GNOME_CDROM_STATUS_NO_DISC || status->cd == GNOME_CDROM_STATUS_EMPTY_DISC) && i < 4) 
 			gtk_widget_set_sensitive (item, FALSE);
         
 		gtk_widget_show (item);
@@ -504,15 +509,15 @@ set_volume (GnomeCD *gcd)
 	gint scaled_volume;
 	double volume;
 	
-	scaled_volume = gconf_client_get_int (client, "/apps/gnome-cd/volume", NULL);
+	scaled_volume = gconf_client_get_int (gcd->client, "/apps/gnome-cd/volume", NULL);
 	/* On error set the Key */	
 	if (scaled_volume < 0) {
 		scaled_volume = 0;
-		gconf_client_set_int (client, "/apps/gnome-cd/volume", 0, NULL);
+		gconf_client_set_int (gcd->client, "/apps/gnome-cd/volume", 0, NULL);
 	}	
 	else if (scaled_volume > 100) {
 		scaled_volume = 100;
-		gconf_client_set_int (client, "/apps/gnome-cd/volume", 100, NULL);
+		gconf_client_set_int (gcd->client, "/apps/gnome-cd/volume", 100, NULL);
 	}
 	volume = ((double)scaled_volume/100)*255;
         
@@ -595,6 +600,7 @@ init_player (const char *device_override)
 	gcd = g_new0 (GnomeCD, 1);
 
 	gcd->not_ready = TRUE;
+	gcd->client = gconf_client_get_default ();
 	gcd->preferences = (GnomeCDPreferences *)preferences_new (gcd);
 	gcd->device_override = g_strdup (device_override);
 	
@@ -706,13 +712,17 @@ init_player (const char *device_override)
 
 	gcd->display = GTK_WIDGET (cd_display_new ());
 	GTK_WIDGET_SET_FLAGS (gcd->display, GTK_CAN_FOCUS | GTK_CAN_DEFAULT);
+	
+	gtk_widget_add_events (gcd->display, GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK); 
+	
 	g_signal_connect (G_OBJECT (gcd->display), "loopmode-changed",
 			  G_CALLBACK (loopmode_changed_cb), gcd);
 	g_signal_connect (G_OBJECT (gcd->display), "playmode-changed",
 			  G_CALLBACK (playmode_changed_cb), gcd);
 	g_signal_connect (G_OBJECT (gcd->display), "style_set",
 			  G_CALLBACK (cd_display_set_style), NULL);
-
+	g_signal_connect (G_OBJECT (gcd->display), "remainingtime-mode-changed",
+			  G_CALLBACK (remainingtime_mode_changed_cb), gcd);
 	/* Theme needs to be loaded after the display is created */
 	gcd->theme = (GCDTheme *)theme_load (gcd, gcd->preferences->theme_name);
 	if (gcd->theme == NULL) {
@@ -786,7 +796,7 @@ init_player (const char *device_override)
 	
 	/* Set the initial volume */
 	set_volume (gcd);
-	volume_notify_id = gconf_client_notify_add (client,
+	volume_notify_id = gconf_client_notify_add (gcd->client,
 			"/apps/gnome-cd/volume", volume_changed_cb,
 			gcd, NULL, &error);
 	if (error != NULL) {
@@ -860,6 +870,7 @@ void
 tray_icon_create (GnomeCD *gcd)
 {
 	GdkPixbuf *pixbuf;
+	GdkPixbuf *icon;
 	GtkWidget *box;
 
 	/* Tray icon */
@@ -876,11 +887,17 @@ tray_icon_create (GnomeCD *gcd)
 				(GDestroyNotify) tray_object_destroyed);
 
 	gtk_container_add (GTK_CONTAINER (gcd->tray), box);
-	pixbuf = gdk_pixbuf_scale_simple (pixbuf_from_file ("gnome-cd/cd.png"),
+	
+	icon = pixbuf_from_file ("gnome-cd/cd.png");
+	pixbuf = gdk_pixbuf_scale_simple (icon,
 				16, 16, GDK_INTERP_BILINEAR);
 	gcd->tray_icon = gtk_image_new_from_pixbuf (pixbuf);
 	g_signal_connect (G_OBJECT (gcd->tray_icon), "expose_event",
 			 	G_CALLBACK (tray_icon_expose), gcd);
+			 	
+	g_object_unref (G_OBJECT (pixbuf));
+	g_object_unref (G_OBJECT (icon));
+
 	GTK_WIDGET_SET_FLAGS (box, GTK_CAN_FOCUS);
 	atk_object_set_name (gtk_widget_get_accessible (box), _("CD Player"));
 	gtk_container_add (GTK_CONTAINER (box), gcd->tray_icon);
